# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import InvalidArgumentType, RequiredArgument
from gvm.protocols.gmpv208 import InfoType


class GmpGetInfoTestMixin:
    def test_get_info(self):
        self.gmp.get_info(info_type=InfoType.CERT_BUND_ADV, info_id="i1")

        self.connection.send.has_been_called_with(
            '<get_info info_id="i1" type="CERT_BUND_ADV" details="1"/>'
        )

        self.gmp.get_info("i1", InfoType.CPE)

        self.connection.send.has_been_called_with(
            '<get_info info_id="i1" type="CPE" details="1"/>'
        )

        self.gmp.get_info("i1", InfoType.CVE)

        self.connection.send.has_been_called_with(
            '<get_info info_id="i1" type="CVE" details="1"/>'
        )

        self.gmp.get_info("i1", InfoType.DFN_CERT_ADV)

        self.connection.send.has_been_called_with(
            '<get_info info_id="i1" type="DFN_CERT_ADV" details="1"/>'
        )

        self.gmp.get_info("i1", InfoType.OVALDEF)

        self.connection.send.has_been_called_with(
            '<get_info info_id="i1" type="OVALDEF" details="1"/>'
        )

        self.gmp.get_info("i1", InfoType.NVT)

        self.connection.send.has_been_called_with(
            '<get_info info_id="i1" type="NVT" details="1"/>'
        )

        with self.assertRaises(AttributeError):
            self.gmp.get_info(
                "i1", InfoType.ALLINFO  # pylint: disable=no-member
            )

    def test_get_info_missing_info_type(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.get_info(info_id="i1", info_type=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.get_info(info_id="i1", info_type="")

        with self.assertRaises(RequiredArgument):
            self.gmp.get_info("i1", "")

    def test_get_info_invalid_info_type(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.get_info(info_id="i1", info_type="foo")

    def test_get_info_missing_info_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.get_info(info_id="", info_type=InfoType.CPE)

        with self.assertRaises(RequiredArgument):
            self.gmp.get_info("", info_type=InfoType.CPE)

        with self.assertRaises(RequiredArgument):
            self.gmp.get_info(info_id=None, info_type=InfoType.CPE)



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from decimal import Decimal

from gvm.errors import InvalidArgument, InvalidArgumentType, RequiredArgument
from gvm.protocols.gmpv208 import SeverityLevel


class GmpCreateOverrideTestMixin:
    def test_create_override(self):
        self.gmp.create_override("foo", nvt_oid="oid1")

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "</create_override>"
        )

    def test_create_override_missing_text(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_override(None, "od1")

        with self.assertRaises(RequiredArgument):
            self.gmp.create_override("", "oid1")

    def test_create_override_missing_nvt_oid(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_override("foo", None)

        with self.assertRaises(RequiredArgument):
            self.gmp.create_override("foo", "")

    def test_create_override_with_hosts(self):
        self.gmp.create_override("foo", nvt_oid="oid1", hosts=[])

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "</create_override>"
        )

        self.gmp.create_override("foo", nvt_oid="oid1", hosts=["h1", "h2"])

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<hosts>h1,h2</hosts>"
            "</create_override>"
        )

    def test_create_override_with_port(self):
        self.gmp.create_override("foo", nvt_oid="oid1", port="666/tcp")

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<port>666/tcp</port>"
            "</create_override>"
        )

    def test_create_override_with_result_id(self):
        self.gmp.create_override("foo", nvt_oid="oid1", result_id="r1")

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            '<result id="r1"/>'
            "</create_override>"
        )

    def test_create_override_with_task_id(self):
        self.gmp.create_override("foo", nvt_oid="oid1", task_id="t1")

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            '<task id="t1"/>'
            "</create_override>"
        )

    def test_create_override_with_severity(self):
        self.gmp.create_override("foo", nvt_oid="oid1", severity="5.5")

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<severity>5.5</severity>"
            "</create_override>"
        )

        self.gmp.create_override("foo", nvt_oid="oid1", severity=5.5)

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<severity>5.5</severity>"
            "</create_override>"
        )

        self.gmp.create_override("foo", nvt_oid="oid1", severity=Decimal(5.5))

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<severity>5.5</severity>"
            "</create_override>"
        )

    def test_create_override_with_new_severity(self):
        self.gmp.create_override("foo", nvt_oid="oid1", new_severity="5.5")

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<new_severity>5.5</new_severity>"
            "</create_override>"
        )

        self.gmp.create_override("foo", nvt_oid="oid1", new_severity=5.5)

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<new_severity>5.5</new_severity>"
            "</create_override>"
        )

        self.gmp.create_override(
            "foo", nvt_oid="oid1", new_severity=Decimal(5.5)
        )

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<new_severity>5.5</new_severity>"
            "</create_override>"
        )

    def test_create_override_with_threat(self):
        self.gmp.create_override(
            "foo", nvt_oid="oid1", threat=SeverityLevel.HIGH
        )

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<threat>High</threat>"
            "</create_override>"
        )

    def test_create_override_invalid_threat(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_override("foo", nvt_oid="oid1", threat="")

        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_override("foo", nvt_oid="oid1", threat="foo")

    def test_create_override_with_new_threat(self):
        self.gmp.create_override(
            "foo", nvt_oid="oid1", new_threat=SeverityLevel.HIGH
        )

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<new_threat>High</new_threat>"
            "</create_override>"
        )

    def test_create_override_invalid_new_threat(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_override("foo", nvt_oid="oid1", new_threat="")

        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_override("foo", nvt_oid="oid1", new_threat="foo")

    def test_create_override_with_days_active(self):
        self.gmp.create_override("foo", nvt_oid="oid1", days_active=0)

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<active>0</active>"
            "</create_override>"
        )

        self.gmp.create_override("foo", nvt_oid="oid1", days_active=-1)

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<active>-1</active>"
            "</create_override>"
        )

        self.gmp.create_override("foo", nvt_oid="oid1", days_active=3600)

        self.connection.send.has_been_called_with(
            "<create_override>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<active>3600</active>"
            "</create_override>"
        )

    def test_create_override_with_invalid_port(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.create_override(text="foo", nvt_oid="oid1", port="123")

        with self.assertRaises(InvalidArgument):
            self.gmp.create_override(text="foo", nvt_oid="oid1", port="tcp/123")



# -*- coding: utf-8 -*-
# Copyright (C) 2021-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from ...gmpv208.entities.tasks import (
    GmpCloneTaskTestMixin,
    GmpCreateContainerTaskTestMixin,
    GmpCreateTaskTestMixin,
    GmpDeleteTaskTestMixin,
    GmpGetTasksTestMixin,
    GmpGetTaskTestMixin,
    GmpModifyTaskTestMixin,
    GmpMoveTaskTestMixin,
    GmpResumeTaskTestMixin,
    GmpStartTaskTestMixin,
    GmpStopTaskTestMixin,
)
from ...gmpv214 import Gmpv214TestCase


class Gmpv214CloneTaskTestCase(GmpCloneTaskTestMixin, Gmpv214TestCase):
    pass


class Gmpv214CreateContainerTaskTestCase(
    GmpCreateContainerTaskTestMixin, Gmpv214TestCase
):
    pass


class Gmpv214CreateTaskTestCase(GmpCreateTaskTestMixin, Gmpv214TestCase):
    pass


class Gmpv214DeleteTaskTestCase(GmpDeleteTaskTestMixin, Gmpv214TestCase):
    pass


class Gmpv214GetTaskTestCase(GmpGetTaskTestMixin, Gmpv214TestCase):
    pass


class Gmpv214GetTasksTestCase(GmpGetTasksTestMixin, Gmpv214TestCase):
    pass


class Gmpv214ModifyTaskTestCase(GmpModifyTaskTestMixin, Gmpv214TestCase):
    pass


class Gmpv214MoveTaskTestCase(GmpMoveTaskTestMixin, Gmpv214TestCase):
    pass


class Gmpv214ResumeTaskTestCase(GmpResumeTaskTestMixin, Gmpv214TestCase):
    pass


class Gmpv214StartTaskTestCase(GmpStartTaskTestMixin, Gmpv214TestCase):
    pass


class Gmpv214StopTaskTestCase(GmpStopTaskTestMixin, Gmpv214TestCase):
    pass



# -*- coding: utf-8 -*-
# Copyright (C) 2021-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from ...gmpv208.entities.policies import (
    GmpClonePolicyTestMixin,
    GmpCreatePolicyTestMixin,
    GmpDeletePolicyTestMixin,
    GmpGetPoliciesTestMixin,
    GmpGetPolicyTestMixin,
    GmpImportPolicyTestMixin,
    GmpModifyPolicySetCommentTestMixin,
    GmpModifyPolicySetFamilySelectionTestMixin,
    GmpModifyPolicySetNameTestMixin,
    GmpModifyPolicySetNvtPreferenceTestMixin,
    GmpModifyPolicySetNvtSelectionTestMixin,
    GmpModifyPolicySetScannerPreferenceTestMixin,
)
from ...gmpv224 import Gmpv224TestCase


class Gmpv224ClonePolicyTestCase(GmpClonePolicyTestMixin, Gmpv224TestCase):
    pass


class Gmpv224CreatePolicyTestCase(GmpCreatePolicyTestMixin, Gmpv224TestCase):
    pass


class Gmpv224DeletePolicyTestCase(GmpDeletePolicyTestMixin, Gmpv224TestCase):
    pass


class Gmpv224GetPolicyTestCase(GmpGetPolicyTestMixin, Gmpv224TestCase):
    pass


class Gmpv224GetPoliciesTestCase(GmpGetPoliciesTestMixin, Gmpv224TestCase):
    pass


class Gmpv224ImportPolicyTestCase(GmpImportPolicyTestMixin, Gmpv224TestCase):
    pass


class Gmpv224ModifyPolicySetCommentTestCase(
    GmpModifyPolicySetCommentTestMixin, Gmpv224TestCase
):
    pass


class Gmpv224ModifyPolicySetFamilySelectionTestCase(
    GmpModifyPolicySetFamilySelectionTestMixin, Gmpv224TestCase
):
    pass


class Gmpv224ModifyPolicySetNvtSelectionTestCase(
    GmpModifyPolicySetNvtSelectionTestMixin, Gmpv224TestCase
):
    pass


class Gmpv224ModifyPolicySetNameTestCase(
    GmpModifyPolicySetNameTestMixin, Gmpv224TestCase
):
    pass


class Gmpv224ModifyPolicySetNvtPreferenceTestCase(
    GmpModifyPolicySetNvtPreferenceTestMixin, Gmpv224TestCase
):
    pass


class Gmpv224ModifyPolicySetScannerPreferenceTestCase(
    GmpModifyPolicySetScannerPreferenceTestMixin, Gmpv224TestCase
):
    pass



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import InvalidArgumentType, RequiredArgument
from gvm.protocols.gmpv208 import ScannerType


class GmpModifyScannerTestMixin:
    def test_modify_scanner(self):
        self.gmp.modify_scanner(scanner_id="s1")

        self.connection.send.has_been_called_with(
            '<modify_scanner scanner_id="s1"/>'
        )

    def test_modify_scanner_missing_scanner_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_scanner(scanner_id=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_scanner(scanner_id="")

    def test_modify_scanner_with_comment(self):
        self.gmp.modify_scanner(scanner_id="s1", comment="foo")

        self.connection.send.has_been_called_with(
            '<modify_scanner scanner_id="s1">'
            "<comment>foo</comment>"
            "</modify_scanner>"
        )

    def test_modify_scanner_with_host(self):
        self.gmp.modify_scanner(scanner_id="s1", host="foo")

        self.connection.send.has_been_called_with(
            '<modify_scanner scanner_id="s1">'
            "<host>foo</host>"
            "</modify_scanner>"
        )

    def test_modify_scanner_with_port(self):
        self.gmp.modify_scanner(scanner_id="s1", port=1234)

        self.connection.send.has_been_called_with(
            '<modify_scanner scanner_id="s1">'
            "<port>1234</port>"
            "</modify_scanner>"
        )

        self.gmp.modify_scanner(scanner_id="s1", port="1234")

        self.connection.send.has_been_called_with(
            '<modify_scanner scanner_id="s1">'
            "<port>1234</port>"
            "</modify_scanner>"
        )

    def test_modify_scanner_with_name(self):
        self.gmp.modify_scanner(scanner_id="s1", name="foo")

        self.connection.send.has_been_called_with(
            '<modify_scanner scanner_id="s1">'
            "<name>foo</name>"
            "</modify_scanner>"
        )

    def test_modify_scanner_with_ca_pub(self):
        self.gmp.modify_scanner(scanner_id="s1", ca_pub="foo")

        self.connection.send.has_been_called_with(
            '<modify_scanner scanner_id="s1">'
            "<ca_pub>foo</ca_pub>"
            "</modify_scanner>"
        )

    def test_modify_scanner_with_credential_id(self):
        self.gmp.modify_scanner(scanner_id="s1", credential_id="c1")

        self.connection.send.has_been_called_with(
            '<modify_scanner scanner_id="s1">'
            '<credential id="c1"/>'
            "</modify_scanner>"
        )

    def test_modify_scanner_with_scanner_type(self):
        self.gmp.modify_scanner(
            scanner_id="s1", scanner_type=ScannerType.OSP_SCANNER_TYPE
        )

        self.connection.send.has_been_called_with(
            '<modify_scanner scanner_id="s1">'
            "<type>1</type>"
            "</modify_scanner>"
        )

        self.gmp.modify_scanner(
            scanner_id="s1", scanner_type=ScannerType.OPENVAS_SCANNER_TYPE
        )

        self.connection.send.has_been_called_with(
            '<modify_scanner scanner_id="s1">'
            "<type>2</type>"
            "</modify_scanner>"
        )

        self.gmp.modify_scanner(
            scanner_id="s1", scanner_type=ScannerType.CVE_SCANNER_TYPE
        )

        self.connection.send.has_been_called_with(
            '<modify_scanner scanner_id="s1">'
            "<type>3</type>"
            "</modify_scanner>"
        )

        self.gmp.modify_scanner(
            scanner_id="s1", scanner_type=ScannerType.GMP_SCANNER_TYPE
        )

        self.connection.send.has_been_called_with(
            '<modify_scanner scanner_id="s1">'
            "<type>4</type>"
            "</modify_scanner>"
        )

    def test_modify_scanner_invalid_scanner_type(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_scanner(scanner_id="s1", scanner_type="")

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_scanner(scanner_id="s1", scanner_type="-1")

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_scanner(scanner_id="s1", scanner_type=1)



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
import warnings

from gvm.errors import InvalidArgument, RequiredArgument


class GmpModifyScanConfigTestMixin:
    def test_modify_scan_config_invalid_selection(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.modify_scan_config(config_id="c1", selection="foo")

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_scan_config(config_id="c1", selection="")

    def test_modify_scan_config_missing_config_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_scan_config(config_id=None, selection="nvt_pref")

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_scan_config(config_id="", selection="nvt_pref")

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_scan_config("", selection="nvt_pref")

    def test_modify_scan_config_set_comment(self):
        # pylint: disable=invalid-name
        with warnings.catch_warnings(record=True) as w:
            warnings.simplefilter("always")

            self.gmp.modify_scan_config(
                config_id="c1", selection=None, comment="foo"
            )

            self.assertEqual(len(w), 1)
            self.assertTrue(issubclass(w[0].category, DeprecationWarning))

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<comment>foo</comment>"
            "</modify_config>"
        )

    def test_modify_scan_config_set_nvt_pref(self):
        # pylint: disable=invalid-name
        with warnings.catch_warnings(record=True) as w:
            warnings.simplefilter("always")

            self.gmp.modify_scan_config(
                config_id="c1", selection="nvt_pref", nvt_oid="o1", name="foo"
            )

            self.assertEqual(len(w), 1)
            self.assertTrue(issubclass(w[0].category, DeprecationWarning))

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<preference>"
            '<nvt oid="o1"/>'
            "<name>foo</name>"
            "</preference>"
            "</modify_config>"
        )

    def test_modify_scan_config_set_scanner_pref(self):
        # pylint: disable=invalid-name
        with warnings.catch_warnings(record=True) as w:
            warnings.simplefilter("always")

            self.gmp.modify_scan_config(
                config_id="c1", selection="scan_pref", name="foo", value="bar"
            )

            self.assertEqual(len(w), 1)
            self.assertTrue(issubclass(w[0].category, DeprecationWarning))

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<preference>"
            "<name>foo</name>"
            "<value>YmFy</value>"
            "</preference>"
            "</modify_config>"
        )

    def test_modify_scan_config_set_nvt_selection(self):
        # pylint: disable=invalid-name
        with warnings.catch_warnings(record=True) as w:
            warnings.simplefilter("always")

            self.gmp.modify_scan_config(
                config_id="c1",
                selection="nvt_selection",
                nvt_oids=["o1"],
                family="foo",
            )

            self.assertEqual(len(w), 1)
            self.assertTrue(issubclass(w[0].category, DeprecationWarning))

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<nvt_selection>"
            "<family>foo</family>"
            '<nvt oid="o1"/>'
            "</nvt_selection>"
            "</modify_config>"
        )

    def test_modify_scan_config_set_family_selection(self):
        # pylint: disable=invalid-name
        with warnings.catch_warnings(record=True) as w:
            warnings.simplefilter("always")

            self.gmp.modify_scan_config(
                config_id="c1",
                selection="family_selection",
                families=[("foo", True, True)],
            )

            self.assertEqual(len(w), 1)
            self.assertTrue(issubclass(w[0].category, DeprecationWarning))

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<family_selection>"
            "<growing>1</growing>"
            "<family>"
            "<name>foo</name>"
            "<all>1</all>"
            "<growing>1</growing>"
            "</family>"
            "</family_selection>"
            "</modify_config>"
        )



# -*- coding: utf-8 -*-
# Copyright (C) 2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from gvm.utils import check_port


class TestCheckPort(unittest.TestCase):
    def test_port_cpe(self):
        self.assertTrue(check_port("cpe:meh:moo*"))

    def test_port_cpe_fail(self):
        self.assertFalse(check_port("cpe:meh haha"))

    def test_port_general(self):
        self.assertTrue(check_port("general/tcp"))

    def test_ports(self):
        self.assertTrue(check_port("1/tcp"))
        self.assertTrue(check_port("12/tcp"))
        self.assertTrue(check_port("123/tcp"))
        self.assertTrue(check_port("1234/tcp"))
        self.assertTrue(check_port("12345/tcp"))
        self.assertTrue(check_port("1/udp"))
        self.assertTrue(check_port("12/udp"))

    def test_ports_fail(self):
        self.assertFalse(check_port("1"))
        self.assertFalse(check_port("1//udp"))
        self.assertFalse(check_port("1/12/tcp"))
        self.assertFalse(check_port("tcp"))
        self.assertFalse(check_port("general"))
        self.assertFalse(check_port("lol"))



# -*- coding: utf-8 -*-
# Copyright (C) 2020-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import InvalidArgument, InvalidArgumentType, RequiredArgument


class GmpModifyPolicySetFamilySelectionTestMixin:
    def test_modify_policy_set_family_selection(self):
        self.gmp.modify_policy_set_family_selection(
            policy_id="c1", families=[("foo", True, True)]
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<family_selection>"
            "<growing>1</growing>"
            "<family>"
            "<name>foo</name>"
            "<all>1</all>"
            "<growing>1</growing>"
            "</family>"
            "</family_selection>"
            "</modify_config>"
        )

        self.gmp.modify_policy_set_family_selection(
            policy_id="c1", families=(("foo", True, True), ("bar", True, True))
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<family_selection>"
            "<growing>1</growing>"
            "<family>"
            "<name>foo</name>"
            "<all>1</all>"
            "<growing>1</growing>"
            "</family>"
            "<family>"
            "<name>bar</name>"
            "<all>1</all>"
            "<growing>1</growing>"
            "</family>"
            "</family_selection>"
            "</modify_config>"
        )

        self.gmp.modify_policy_set_family_selection(
            policy_id="c1",
            families=[("foo", True, False), ("bar", False, True)],
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<family_selection>"
            "<growing>1</growing>"
            "<family>"
            "<name>foo</name>"
            "<all>0</all>"
            "<growing>1</growing>"
            "</family>"
            "<family>"
            "<name>bar</name>"
            "<all>1</all>"
            "<growing>0</growing>"
            "</family>"
            "</family_selection>"
            "</modify_config>"
        )

    def test_modify_policy_set_family_selection_missing_config_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_family_selection(
                policy_id=None, families=[("foo", True, True)]
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_family_selection(
                policy_id="", families=[("foo", True, True)]
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_family_selection(
                "", [("foo", True, True)]
            )

    def test_modify_policy_set_family_selection_invalid_families(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_policy_set_family_selection(
                policy_id="c1", families=None
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_policy_set_family_selection(
                policy_id="c1", families=""
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_policy_set_family_selection("c1", "")

    def test_modify_policy_set_family_selection_with_auto_add_new_families(
        self,
    ):
        self.gmp.modify_policy_set_family_selection(
            policy_id="c1",
            families=[("foo", True, True)],
            auto_add_new_families=True,
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<family_selection>"
            "<growing>1</growing>"
            "<family>"
            "<name>foo</name>"
            "<all>1</all>"
            "<growing>1</growing>"
            "</family>"
            "</family_selection>"
            "</modify_config>"
        )

        self.gmp.modify_policy_set_family_selection(
            policy_id="c1",
            families=[("foo", True, True)],
            auto_add_new_families=False,
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<family_selection>"
            "<growing>0</growing>"
            "<family>"
            "<name>foo</name>"
            "<all>1</all>"
            "<growing>1</growing>"
            "</family>"
            "</family_selection>"
            "</modify_config>"
        )

    def test_modify_policy_set_family_selection_with_auto_add_new_nvts(self):
        self.gmp.modify_policy_set_family_selection(
            policy_id="c1", families=[("foo", True, True)]
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<family_selection>"
            "<growing>1</growing>"
            "<family>"
            "<name>foo</name>"
            "<all>1</all>"
            "<growing>1</growing>"
            "</family>"
            "</family_selection>"
            "</modify_config>"
        )

        self.gmp.modify_policy_set_family_selection(
            policy_id="c1", families=[("foo", False, True)]
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<family_selection>"
            "<growing>1</growing>"
            "<family>"
            "<name>foo</name>"
            "<all>1</all>"
            "<growing>0</growing>"
            "</family>"
            "</family_selection>"
            "</modify_config>"
        )

        self.gmp.modify_policy_set_family_selection(
            policy_id="c1",
            families=[("foo", False, True), ("bar", True, False)],
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<family_selection>"
            "<growing>1</growing>"
            "<family>"
            "<name>foo</name>"
            "<all>1</all>"
            "<growing>0</growing>"
            "</family>"
            "<family>"
            "<name>bar</name>"
            "<all>0</all>"
            "<growing>1</growing>"
            "</family>"
            "</family_selection>"
            "</modify_config>"
        )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_policy_set_family_selection(
                policy_id="c1", families=[("foo", "False", "True")]
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_policy_set_family_selection(
                policy_id="c1", families=[("foo", True, None)]
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_policy_set_family_selection(
                policy_id="c1", families=[("foo", "True", False)]
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_policy_set_family_selection(
                policy_id="c1", families=[("foo",)]
            )



# -*- coding: utf-8 -*-
# Copyright (C) 2019-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from gvm.errors import (
    GvmError,
    GvmResponseError,
    GvmServerError,
    InvalidArgument,
    InvalidArgumentType,
    RequiredArgument,
)


class InvalidArgumentTestCase(unittest.TestCase):
    def test_raise_with_message(self):
        with self.assertRaisesRegex(InvalidArgument, "^foo bar$"):
            raise InvalidArgument("foo bar")

    def test_message_precedence(self):
        with self.assertRaisesRegex(InvalidArgument, "^foo bar$") as cm:
            raise InvalidArgument("foo bar", argument="foo", function="bar")

        ex = cm.exception
        self.assertEqual(ex.argument, "foo")
        self.assertEqual(ex.function, "bar")

        self.assertEqual(str(ex), "foo bar")

    def test_raise_with_argument(self):
        with self.assertRaises(InvalidArgument) as cm:
            raise InvalidArgument(argument="foo")

        ex = cm.exception
        self.assertEqual(ex.argument, "foo")
        self.assertIsNone(ex.function)

    def test_raise_with_function(self):
        with self.assertRaises(InvalidArgument) as cm:
            raise InvalidArgument(function="foo")

        ex = cm.exception
        self.assertEqual(ex.function, "foo")
        self.assertIsNone(ex.argument)

    def test_raise_with_argument_and_function(self):
        with self.assertRaises(InvalidArgument) as cm:
            raise InvalidArgument(argument="foo", function="bar")

        ex = cm.exception
        self.assertEqual(ex.argument, "foo")
        self.assertEqual(ex.function, "bar")

    def test_string_conversion(self):
        with self.assertRaises(InvalidArgument) as cm:
            raise InvalidArgument("foo bar", argument="foo")

        ex = cm.exception
        self.assertEqual(str(ex), "foo bar")

        with self.assertRaises(InvalidArgument) as cm:
            raise InvalidArgument(argument="foo")

        ex = cm.exception
        self.assertEqual(str(ex), "Invalid argument foo")

        with self.assertRaises(InvalidArgument) as cm:
            raise InvalidArgument(function="foo")

        ex = cm.exception
        self.assertEqual(str(ex), "Invalid argument for foo")

        with self.assertRaises(InvalidArgument) as cm:
            raise InvalidArgument(argument="foo", function="bar")

        ex = cm.exception
        self.assertEqual(str(ex), "Invalid argument foo for bar")

    def test_is_gvm_error(self):
        with self.assertRaises(GvmError):
            raise InvalidArgument("foo bar")


class RequiredArgumentTestCase(unittest.TestCase):
    def test_raise_with_message(self):
        with self.assertRaisesRegex(RequiredArgument, "^foo bar$"):
            raise RequiredArgument("foo bar")

    def test_message_precedence(self):
        with self.assertRaisesRegex(RequiredArgument, "^foo bar$") as cm:
            raise RequiredArgument("foo bar", argument="foo", function="bar")

        ex = cm.exception
        self.assertEqual(ex.argument, "foo")
        self.assertEqual(ex.function, "bar")

        self.assertEqual(str(ex), "foo bar")

    def test_raise_with_argument(self):
        with self.assertRaises(RequiredArgument) as cm:
            raise RequiredArgument(argument="foo")

        ex = cm.exception
        self.assertEqual(ex.argument, "foo")
        self.assertIsNone(ex.function)

    def test_raise_with_function(self):
        with self.assertRaises(RequiredArgument) as cm:
            raise RequiredArgument(function="foo")

        ex = cm.exception
        self.assertEqual(ex.function, "foo")
        self.assertIsNone(ex.argument)

    def test_raise_with_argument_and_function(self):
        with self.assertRaises(RequiredArgument) as cm:
            raise RequiredArgument(argument="foo", function="bar")

        ex = cm.exception
        self.assertEqual(ex.argument, "foo")
        self.assertEqual(ex.function, "bar")

    def test_string_conversion(self):
        with self.assertRaises(RequiredArgument) as cm:
            raise RequiredArgument("foo bar")

        ex = cm.exception
        self.assertEqual(str(ex), "foo bar")

        with self.assertRaises(RequiredArgument) as cm:
            raise RequiredArgument(argument="foo")

        ex = cm.exception
        self.assertEqual(str(ex), "Required argument foo")

        with self.assertRaises(RequiredArgument) as cm:
            raise RequiredArgument(function="foo")

        ex = cm.exception
        self.assertEqual(str(ex), "Required argument missing for foo")

        with self.assertRaises(RequiredArgument) as cm:
            raise RequiredArgument(argument="foo", function="bar")

        ex = cm.exception
        self.assertEqual(str(ex), "bar requires a foo argument")

    def test_is_gvm_error(self):
        with self.assertRaises(GvmError):
            raise RequiredArgument("foo bar")


class GvmServerErrorTestCase(unittest.TestCase):
    def test_raise_with_message_and_status(self):
        with self.assertRaisesRegex(GvmServerError, "^Server Error foo. bar$"):
            raise GvmServerError("foo", "bar")

    def test_is_gvm_error(self):
        with self.assertRaises(GvmError):
            raise GvmServerError("foo", "bar")


class GvmResponseErrorTestCase(unittest.TestCase):
    def test_raise_with_message_and_status(self):
        with self.assertRaisesRegex(
            GvmResponseError, "^Response Error foo. bar$"
        ):
            raise GvmResponseError("foo", "bar")

    def test_is_gvm_error(self):
        with self.assertRaises(GvmError):
            raise GvmResponseError("foo", "bar")


class InvalidArgumentTypeTestCase(unittest.TestCase):
    def test_raise_with_argument_and_arg_type(self):
        with self.assertRaisesRegex(
            InvalidArgumentType, "^The argument foo must be of type bar.$"
        ):
            raise InvalidArgumentType("foo", "bar")

    def test_raise_with_function(self):
        with self.assertRaisesRegex(
            InvalidArgumentType,
            "^In baz the argument foo must be of type bar.$",
        ):
            raise InvalidArgumentType("foo", "bar", function="baz")

    def test_string_conversion(self):
        with self.assertRaises(InvalidArgumentType) as cm:
            raise InvalidArgumentType("foo", "bar")

        ex = cm.exception
        self.assertEqual(str(ex), "The argument foo must be of type bar.")
        self.assertIsNone(ex.function)

        with self.assertRaises(InvalidArgumentType) as cm:
            raise InvalidArgumentType("foo", "bar", function="baz")

        ex = cm.exception
        self.assertEqual(
            str(ex), "In baz the argument foo must be of type bar."
        )

    def test_is_gvm_error(self):
        with self.assertRaises(GvmError):
            raise InvalidArgumentType("foo", "bar")


if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
# Copyright (C) 2021-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import InvalidArgumentType, RequiredArgument
from gvm.protocols.gmpv214.entities.targets import AliveTest


class GmpModifyTargetTestMixin:
    def test_modify_target(self):
        self.gmp.modify_target(target_id="t1")

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1"/>'
        )

    def test_modify_target_missing_target_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_target(target_id=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_target(target_id="")

    def test_modify_target_with_comment(self):
        self.gmp.modify_target(target_id="t1", comment="foo")

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<comment>foo</comment>"
            "</modify_target>"
        )

    def test_modify_target_with_hosts(self):
        self.gmp.modify_target(target_id="t1", hosts=["foo"])

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<hosts>foo</hosts>"
            "<exclude_hosts></exclude_hosts>"
            "</modify_target>"
        )

        self.gmp.modify_target(target_id="t1", hosts=["foo", "bar"])

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<hosts>foo,bar</hosts>"
            "<exclude_hosts></exclude_hosts>"
            "</modify_target>"
        )

    def test_modify_target_with_hosts_and_exclude_hosts(self):
        self.gmp.modify_target(
            target_id="t1", hosts=["foo", "bar"], exclude_hosts=["foo"]
        )

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<hosts>foo,bar</hosts>"
            "<exclude_hosts>foo</exclude_hosts>"
            "</modify_target>"
        )

    def test_modify_target_with_name(self):
        self.gmp.modify_target(target_id="t1", name="foo")

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<name>foo</name>"
            "</modify_target>"
        )

    def test_modify_target_with_exclude_hosts(self):
        self.gmp.modify_target(target_id="t1", exclude_hosts=["foo"])

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<exclude_hosts>foo</exclude_hosts>"
            "</modify_target>"
        )

        self.gmp.modify_target(target_id="t1", exclude_hosts=["foo", "bar"])

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<exclude_hosts>foo,bar</exclude_hosts>"
            "</modify_target>"
        )

    def test_modify_target_with_ssh_credential(self):
        self.gmp.modify_target(target_id="t1", ssh_credential_id="c1")

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            '<ssh_credential id="c1"/>'
            "</modify_target>"
        )

    def test_modify_target_with_ssh_credential_port(self):
        self.gmp.modify_target(
            target_id="t1", ssh_credential_id="c1", ssh_credential_port=123
        )

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            '<ssh_credential id="c1">'
            "<port>123</port>"
            "</ssh_credential>"
            "</modify_target>"
        )

    def test_modify_target_with_smb_credential_id(self):
        self.gmp.modify_target(target_id="t1", smb_credential_id="c1")

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            '<smb_credential id="c1"/>'
            "</modify_target>"
        )

    def test_modify_target_with_esxi_credential_id(self):
        self.gmp.modify_target(target_id="t1", esxi_credential_id="c1")

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            '<esxi_credential id="c1"/>'
            "</modify_target>"
        )

    def test_modify_target_with_snmp_credential_id(self):
        self.gmp.modify_target(target_id="t1", snmp_credential_id="c1")

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            '<snmp_credential id="c1"/>'
            "</modify_target>"
        )

    def test_modify_target_with_alive_tests(self):
        self.gmp.modify_target(target_id="t1", alive_test=AliveTest.ICMP_PING)

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<alive_tests>ICMP Ping</alive_tests>"
            "</modify_target>"
        )

    def test_modify_target_invalid_alive_tests(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_target(target_id="t1", alive_test="foo")

    def test_modify_target_with_allow_simultaneous_ips(self):
        self.gmp.modify_target(target_id="t1", allow_simultaneous_ips=True)

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<allow_simultaneous_ips>1</allow_simultaneous_ips>"
            "</modify_target>"
        )

        self.gmp.modify_target(target_id="t1", allow_simultaneous_ips=False)

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<allow_simultaneous_ips>0</allow_simultaneous_ips>"
            "</modify_target>"
        )

    def test_modify_target_with_reverse_lookup_only(self):
        self.gmp.modify_target(target_id="t1", reverse_lookup_only=True)

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<reverse_lookup_only>1</reverse_lookup_only>"
            "</modify_target>"
        )

        self.gmp.modify_target(target_id="t1", reverse_lookup_only=False)

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<reverse_lookup_only>0</reverse_lookup_only>"
            "</modify_target>"
        )

    def test_modify_target_with_reverse_lookup_unify(self):
        self.gmp.modify_target(target_id="t1", reverse_lookup_unify=True)

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<reverse_lookup_unify>1</reverse_lookup_unify>"
            "</modify_target>"
        )

        self.gmp.modify_target(target_id="t1", reverse_lookup_unify=False)

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            "<reverse_lookup_unify>0</reverse_lookup_unify>"
            "</modify_target>"
        )

    def test_modify_target_with_port_list_id(self):
        self.gmp.modify_target(target_id="t1", port_list_id="pl1")

        self.connection.send.has_been_called_with(
            '<modify_target target_id="t1">'
            '<port_list id="pl1"/>'
            "</modify_target>"
        )



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import RequiredArgument


class GmpModifyUserSettingTestMixin:
    def test_modify_user_setting(self):
        self.gmp.modify_user_setting(setting_id="s1", value="bar")

        self.connection.send.has_been_called_with(
            '<modify_setting setting_id="s1">'
            "<value>YmFy</value>"
            "</modify_setting>"
        )

        self.gmp.modify_user_setting(name="s1", value="bar")

        self.connection.send.has_been_called_with(
            "<modify_setting>"
            "<name>s1</name>"
            "<value>YmFy</value>"
            "</modify_setting>"
        )

        self.gmp.modify_user_setting(setting_id="s1", value="")

        self.connection.send.has_been_called_with(
            '<modify_setting setting_id="s1">'
            "<value></value>"
            "</modify_setting>"
        )

    def test_modify_user_setting_missing_setting_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_user_setting(setting_id=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_user_setting(setting_id="")

    def test_modify_setting_missing_name(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_user_setting(name=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_user_setting(name="")

    def test_modify_user_setting_missing_value(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_user_setting(setting_id="s1", value=None)



# -*- coding: utf-8 -*-
# Copyright (C) 2020-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import InvalidArgumentType, RequiredArgument


class GmpModifyPolicySetNvtSelectionTestMixin:
    def test_modify_policy_set_nvt_selection(self):
        self.gmp.modify_policy_set_nvt_selection(
            policy_id="c1", family="foo", nvt_oids=["o1"]
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<nvt_selection>"
            "<family>foo</family>"
            '<nvt oid="o1"/>'
            "</nvt_selection>"
            "</modify_config>"
        )

        self.gmp.modify_policy_set_nvt_selection(
            policy_id="c1", family="foo", nvt_oids=["o1", "o2"]
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<nvt_selection>"
            "<family>foo</family>"
            '<nvt oid="o1"/>'
            '<nvt oid="o2"/>'
            "</nvt_selection>"
            "</modify_config>"
        )

        self.gmp.modify_policy_set_nvt_selection("c1", "foo", ["o1"])

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<nvt_selection>"
            "<family>foo</family>"
            '<nvt oid="o1"/>'
            "</nvt_selection>"
            "</modify_config>"
        )

        self.gmp.modify_policy_set_nvt_selection("c1", "foo", ("o1", "o2"))

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<nvt_selection>"
            "<family>foo</family>"
            '<nvt oid="o1"/>'
            '<nvt oid="o2"/>'
            "</nvt_selection>"
            "</modify_config>"
        )

        self.gmp.modify_policy_set_nvt_selection(
            policy_id="c1", family="foo", nvt_oids=[]
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<nvt_selection>"
            "<family>foo</family>"
            "</nvt_selection>"
            "</modify_config>"
        )

    def test_modify_policy_set_nvt_selection_missing_config_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_nvt_selection(
                policy_id=None, family="foo", nvt_oids=["o1"]
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_nvt_selection(
                policy_id="", family="foo", nvt_oids=["o1"]
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_nvt_selection("", "foo", ["o1"])

    def test_modify_policy_set_nvt_selection_missing_family(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_nvt_selection(
                policy_id="c1", family=None, nvt_oids=["o1"]
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_nvt_selection(
                policy_id="c1", family="", nvt_oids=["o1"]
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_nvt_selection("c1", "", ["o1"])

    def test_modify_policy_set_nvt_selection_invalid_nvt_oids(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_policy_set_nvt_selection(
                policy_id="c1", family="foo", nvt_oids=None
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_policy_set_nvt_selection(
                policy_id="c1", family="foo", nvt_oids=""
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_policy_set_nvt_selection("c1", "foo", "")



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import InvalidArgument, InvalidArgumentType, RequiredArgument
from gvm.protocols.gmpv208 import AlertCondition, AlertEvent, AlertMethod


class GmpCreateAlertTestMixin:
    def test_missing_name(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_alert(
                name="",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TASK_RUN_STATUS_CHANGED,
                method=AlertMethod.EMAIL,
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.create_alert(
                name=None,
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TASK_RUN_STATUS_CHANGED,
                method=AlertMethod.EMAIL,
            )

    def test_missing_condition(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_alert(
                name="foo", condition="", event="bar", method="lorem"
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.create_alert(
                name="foo", condition=None, event="bar", method="lorem"
            )

    def test_missing_event(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_alert(
                name="foo", condition="bar", event="", method="lorem"
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.create_alert(
                name="foo", condition="bar", event=None, method="lorem"
            )

    def test_missing_method(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_alert(
                name="foo", condition="bar", event="lorem", method=""
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.create_alert(
                name="foo", condition="bar", event="lorem", method=None
            )

    def test_invalid_condition(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_alert(
                name="foo",
                condition="bar",
                event=AlertEvent.TASK_RUN_STATUS_CHANGED,
                method=AlertMethod.EMAIL,
            )

    def test_invalid_event(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event="lorem",
                method=AlertMethod.EMAIL,
            )

    def test_invalid_method(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TASK_RUN_STATUS_CHANGED,
                method="ipsum",
            )

    def test_invalid_condition_for_secinfo(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.SEVERITY_AT_LEAST,
                event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                method=AlertMethod.EMAIL,
            )

    def test_invalid_method_for_secinfo(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                method=AlertMethod.HTTP_GET,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                method=AlertMethod.ALEMBA_VFIRE,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                method=AlertMethod.SOURCEFIRE_CONNECTOR,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                method=AlertMethod.START_TASK,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                method=AlertMethod.TIPPINGPOINT_SMS,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                method=AlertMethod.VERINICE_CONNECTOR,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.NEW_SECINFO_ARRIVED,
                method=AlertMethod.HTTP_GET,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.NEW_SECINFO_ARRIVED,
                method=AlertMethod.ALEMBA_VFIRE,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.NEW_SECINFO_ARRIVED,
                method=AlertMethod.SOURCEFIRE_CONNECTOR,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.NEW_SECINFO_ARRIVED,
                method=AlertMethod.START_TASK,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.NEW_SECINFO_ARRIVED,
                method=AlertMethod.TIPPINGPOINT_SMS,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.NEW_SECINFO_ARRIVED,
                method=AlertMethod.VERINICE_CONNECTOR,
            )

    def test_missing_method_for_ticket_received(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TICKET_RECEIVED,
                method=None,
            )

    def test_missing_condition_for_ticket_received(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_alert(
                name="foo",
                condition=None,
                event=AlertEvent.TICKET_RECEIVED,
                method=AlertMethod.EMAIL,
            )

    def test_invalid_method_for_ticket_received(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TICKET_RECEIVED,
                method=AlertMethod.HTTP_GET,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TICKET_RECEIVED,
                method=AlertMethod.SCP,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TICKET_RECEIVED,
                method=AlertMethod.SEND,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TICKET_RECEIVED,
                method=AlertMethod.SMB,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TICKET_RECEIVED,
                method=AlertMethod.SNMP,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TICKET_RECEIVED,
                method=AlertMethod.ALEMBA_VFIRE,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TICKET_RECEIVED,
                method=AlertMethod.VERINICE_CONNECTOR,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TICKET_RECEIVED,
                method=AlertMethod.TIPPINGPOINT_SMS,
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TICKET_RECEIVED,
                method=AlertMethod.SOURCEFIRE_CONNECTOR,
            )

    def test_invalid_condition_for_task_run_status_changed(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.ERROR,
                event=AlertEvent.TASK_RUN_STATUS_CHANGED,
                method=AlertMethod.EMAIL,
            )

    def test_invalid_condition_for_ticket_received(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.create_alert(
                name="foo",
                condition=AlertCondition.FILTER_COUNT_AT_LEAST,
                event=AlertEvent.TICKET_RECEIVED,
                method=AlertMethod.EMAIL,
            )

    def test_create_alert(self):
        self.gmp.create_alert(
            name="foo",
            condition=AlertCondition.ALWAYS,
            event=AlertEvent.TASK_RUN_STATUS_CHANGED,
            method=AlertMethod.EMAIL,
        )

        self.connection.send.has_been_called_with(
            "<create_alert>"
            "<name>foo</name>"
            "<condition>Always</condition>"
            "<event>Task run status changed</event>"
            "<method>Email</method>"
            "</create_alert>"
        )

    def test_create_alert_with_filter_id(self):
        self.gmp.create_alert(
            name="foo",
            condition=AlertCondition.ALWAYS,
            event=AlertEvent.TASK_RUN_STATUS_CHANGED,
            method=AlertMethod.EMAIL,
            filter_id="f1",
        )

        self.connection.send.has_been_called_with(
            "<create_alert>"
            "<name>foo</name>"
            "<condition>Always</condition>"
            "<event>Task run status changed</event>"
            "<method>Email</method>"
            '<filter id="f1"/>'
            "</create_alert>"
        )

    def test_create_alert_with_comment(self):
        self.gmp.create_alert(
            name="foo",
            condition=AlertCondition.ALWAYS,
            event=AlertEvent.TASK_RUN_STATUS_CHANGED,
            method=AlertMethod.EMAIL,
            comment="hello",
        )

        self.connection.send.has_been_called_with(
            "<create_alert>"
            "<name>foo</name>"
            "<condition>Always</condition>"
            "<event>Task run status changed</event>"
            "<method>Email</method>"
            "<comment>hello</comment>"
            "</create_alert>"
        )

    def test_create_alert_with_condition_data(self):
        self.gmp.create_alert(
            name="foo",
            condition=AlertCondition.ALWAYS,
            event=AlertEvent.TASK_RUN_STATUS_CHANGED,
            method=AlertMethod.EMAIL,
            condition_data={"foo": "bar"},
        )

        self.connection.send.has_been_called_with(
            "<create_alert>"
            "<name>foo</name>"
            "<condition>Always<data>bar<name>foo</name></data></condition>"
            "<event>Task run status changed</event>"
            "<method>Email</method>"
            "</create_alert>"
        )

    def test_create_alert_with_event_data(self):
        self.gmp.create_alert(
            name="foo",
            condition=AlertCondition.ALWAYS,
            event=AlertEvent.TASK_RUN_STATUS_CHANGED,
            method=AlertMethod.EMAIL,
            event_data={"foo": "bar"},
        )

        self.connection.send.has_been_called_with(
            "<create_alert>"
            "<name>foo</name>"
            "<condition>Always</condition>"
            "<event>Task run status changed"
            "<data>bar<name>foo</name></data>"
            "</event>"
            "<method>Email</method>"
            "</create_alert>"
        )

    def test_create_alert_with_method_data(self):
        self.gmp.create_alert(
            name="foo",
            condition=AlertCondition.ALWAYS,
            event=AlertEvent.TASK_RUN_STATUS_CHANGED,
            method=AlertMethod.EMAIL,
            method_data={"foo": "bar"},
        )

        self.connection.send.has_been_called_with(
            "<create_alert>"
            "<name>foo</name>"
            "<condition>Always</condition>"
            "<event>Task run status changed</event>"
            "<method>Email<data>bar<name>foo</name></data></method>"
            "</create_alert>"
        )



# -*- coding: utf-8 -*-
# Copyright (C) 2021-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from ...gmpv208.entities.overrides import (
    GmpCloneOverrideTestMixin,
    GmpDeleteOverrideTestMixin,
    GmpGetOverridesTestMixin,
    GmpGetOverrideTestMixin,
)
from ...gmpv214 import Gmpv214TestCase
from .overrides import GmpCreateOverrideTestMixin, GmpModifyOverrideTestMixin


class Gmpv214CloneOverrideTestCase(GmpCloneOverrideTestMixin, Gmpv214TestCase):
    pass


class Gmpv214CreateOverrideTestCase(
    GmpCreateOverrideTestMixin, Gmpv214TestCase
):
    pass


class Gmpv214DeleteOverrideTestCase(
    GmpDeleteOverrideTestMixin, Gmpv214TestCase
):
    pass


class Gmpv214GetOverrideTestCase(GmpGetOverrideTestMixin, Gmpv214TestCase):
    pass


class Gmpv214GetOverridesTestCase(GmpGetOverridesTestMixin, Gmpv214TestCase):
    pass


class Gmpv214ModifyOverrideTestCase(
    GmpModifyOverrideTestMixin, Gmpv214TestCase
):
    pass



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest
from collections import OrderedDict

from gvm.errors import RequiredArgument
from gvm.protocols.ospv1 import Osp

from .. import MockConnection


class OSPStartScanTestCase(unittest.TestCase):
    def setUp(self):
        self.connection = MockConnection()
        self.osp = Osp(self.connection)

    def test_start_scan(self):
        scanner_params = OrderedDict()
        scanner_params["key1"] = "value1"

        targets = list()
        _target1 = OrderedDict()
        _target1["hosts"] = "localhost"
        _target1["ports"] = "22,80"
        targets.append(_target1)

        _target2 = OrderedDict()
        _target2["hosts"] = "192.168.10.1"
        _target2["ports"] = "443"
        _smb = OrderedDict()
        _smb["username"] = "username"
        _smb["password"] = "pass"
        _smb["port"] = "port"
        _smb["type"] = "type"
        _credential1 = {"smb": _smb}
        _target2["credentials"] = _credential1
        targets.append(_target2)

        vts = OrderedDict()
        vts["vt1"] = {"value_id": "value"}
        vts["vt_groups"] = ["family=A", "family=B"]

        self.osp.start_scan(
            scan_id="123-456",
            parallel=10,
            scanner_params=scanner_params,
            targets=targets,
            vt_selection=vts,
        )

        self.connection.send.has_been_called_with(
            '<start_scan scan_id="123-456" parallel="10">'
            '<scanner_params key1="value1"/>'
            "<targets><target><hosts>localhost</hosts>"
            "<ports>22,80</ports></target>"
            "<target><hosts>192.168.10.1</hosts>"
            "<ports>443</ports>"
            "<credentials>"
            '<credential type="type" port="port" service="smb">'
            "<username>username</username>"
            "<password>pass</password>"
            "</credential></credentials>"
            "</target></targets><vt_selection>"
            '<vt_single id="vt1">'
            '<vt_value id="value_id">value</vt_value></vt_single>'
            '<vt_group filter="family=A"/><vt_group filter="family=B"/>'
            "</vt_selection></start_scan>"
        )

    def test_start_scan_without_target(self):
        with self.assertRaises(RequiredArgument):
            self.osp.start_scan()

    def test_start_scan_legacy(self):
        self.osp.start_scan(
            scan_id="123-456", parallel=10, target="localhost", ports="22"
        )
        self.connection.send.has_been_called_with(
            '<start_scan scan_id="123-456" parallel="10" '
            'target="localhost" ports="22">'
            "<scanner_params/></start_scan>"
        )


if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from collections import OrderedDict

from gvm.errors import InvalidArgument, InvalidArgumentType, RequiredArgument
from gvm.protocols.gmpv208 import HostsOrdering


class GmpModifyTaskTestMixin:
    def test_modify_task(self):
        self.gmp.modify_task("t1")

        self.connection.send.has_been_called_with('<modify_task task_id="t1"/>')

    def test_modify_task_missing_task_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_task(None)

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_task("")

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_task(task_id="")

    def test_modify_task_with_name(self):
        self.gmp.modify_task(task_id="t1", name="foo")

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">' "<name>foo</name>" "</modify_task>"
        )

    def test_modify_task_with_config_id(self):
        self.gmp.modify_task(task_id="t1", config_id="c1")

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">' '<config id="c1"/>' "</modify_task>"
        )

    def test_modify_task_with_target_id(self):
        self.gmp.modify_task(task_id="t1", target_id="t1")

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">' '<target id="t1"/>' "</modify_task>"
        )

    def test_modify_task_with_scanner_id(self):
        self.gmp.modify_task(task_id="t1", scanner_id="s1")

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">' '<scanner id="s1"/>' "</modify_task>"
        )

    def test_modify_task_with_schedule_id(self):
        self.gmp.modify_task(task_id="t1", schedule_id="s1")

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">' '<schedule id="s1"/>' "</modify_task>"
        )

    def test_modify_task_with_comment(self):
        self.gmp.modify_task(task_id="t1", comment="bar")

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">'
            "<comment>bar</comment>"
            "</modify_task>"
        )

    def test_modify_task_with_alerts_ids(self):
        self.gmp.modify_task(task_id="t1", alert_ids=["a1", "a2", "a3"])

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">'
            '<alert id="a1"/>'
            '<alert id="a2"/>'
            '<alert id="a3"/>'
            "</modify_task>"
        )

    def test_modify_task_invalid_alerts_ids(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_task(task_id="t1", alert_ids="")

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_task(task_id="t1", alert_ids="a1")

    def test_modify_task_with_empty_alert_ids(self):
        self.gmp.modify_task(task_id="t1", alert_ids=[])

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">' '<alert id="0"/>' "</modify_task>"
        )

    def test_modify_task_with_alterable(self):
        self.gmp.modify_task(task_id="t1", alterable=True)

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">'
            "<alterable>1</alterable>"
            "</modify_task>"
        )

        self.gmp.modify_task(task_id="t1", alterable=False)

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">'
            "<alterable>0</alterable>"
            "</modify_task>"
        )

    def test_modify_task_with_hosts_ordering(self):
        self.gmp.modify_task(task_id="t1", hosts_ordering=HostsOrdering.REVERSE)

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">'
            "<hosts_ordering>reverse</hosts_ordering>"
            "</modify_task>"
        )

    def test_modify_task_invalid_hosts_ordering(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_task(task_id="t1", hosts_ordering="foo")

    def test_modify_task_with_schedule(self):
        self.gmp.modify_task(task_id="t1", schedule_id="s1")

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">' '<schedule id="s1"/>' "</modify_task>"
        )

    def test_modify_task_with_schedule_periods(self):
        self.gmp.modify_task(task_id="t1", schedule_periods=0)

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">'
            "<schedule_periods>0</schedule_periods>"
            "</modify_task>"
        )

        self.gmp.modify_task(task_id="t1", schedule_periods=5)

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">'
            "<schedule_periods>5</schedule_periods>"
            "</modify_task>"
        )

    def test_modify_task_invalid_schedule_periods(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.modify_task(task_id="t1", schedule_periods="foo")

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_task(task_id="t1", schedule_periods=-1)

    def test_modify_task_with_observers(self):
        self.gmp.modify_task(task_id="t1", observers=["u1", "u2"])

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">'
            "<observers>u1,u2</observers>"
            "</modify_task>"
        )

    def test_modify_task_invalid_observers(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_task(task_id="t1", observers="")

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_task(task_id="t1", observers="foo")

    def test_modify_task_with_preferences(self):
        self.gmp.modify_task(
            task_id="t1",
            preferences=OrderedDict([("foo", "bar"), ("lorem", "ipsum")]),
        )

        self.connection.send.has_been_called_with(
            '<modify_task task_id="t1">'
            "<preferences>"
            "<preference>"
            "<scanner_name>foo</scanner_name>"
            "<value>bar</value>"
            "</preference>"
            "<preference>"
            "<scanner_name>lorem</scanner_name>"
            "<value>ipsum</value>"
            "</preference>"
            "</preferences>"
            "</modify_task>"
        )

    def test_modify_task_invalid_preferences(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_task(task_id="t1", preferences="")

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_task(task_id="t1", preferences=["foo", "bar"])



# -*- coding: utf-8 -*-
# Copyright (C) 2020-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import InvalidArgumentType, RequiredArgument
from gvm.protocols.gmpv208 import (
    CredentialType,
    SnmpAuthAlgorithm,
    SnmpPrivacyAlgorithm,
)


class GmpCreateCredentialTestMixin:
    def test_create_up_credential_missing_name(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_credential(
                name="",
                credential_type=CredentialType.USERNAME_PASSWORD,
                login="foo",
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.create_credential(
                name=None,
                credential_type=CredentialType.USERNAME_PASSWORD,
                login="foo",
            )

    def test_create_up_credential(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.USERNAME_PASSWORD,
            comment="bar",
            login="Max",
            password="123",
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>up</type>"
            "<comment>bar</comment>"
            "<login>Max</login>"
            "<password>123</password>"
            "</create_credential>"
        )

    def test_create_up_credential_with_allow_insecure(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.USERNAME_PASSWORD,
            comment="bar",
            login="Max",
            password="123",
            allow_insecure=True,
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>up</type>"
            "<comment>bar</comment>"
            "<allow_insecure>1</allow_insecure>"
            "<login>Max</login>"
            "<password>123</password>"
            "</create_credential>"
        )

        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.USERNAME_PASSWORD,
            comment="bar",
            login="Max",
            password="123",
            allow_insecure=False,
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>up</type>"
            "<comment>bar</comment>"
            "<allow_insecure>0</allow_insecure>"
            "<login>Max</login>"
            "<password>123</password>"
            "</create_credential>"
        )

    def test_create_cc_credential_missing_certificate(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_credential(
                name="foo", credential_type=CredentialType.CLIENT_CERTIFICATE
            )

    def test_create_cc_credential(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.CLIENT_CERTIFICATE,
            certificate="abcdef",
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>cc</type>"
            "<certificate>abcdef</certificate>"
            "</create_credential>"
        )

    def test_create_cc_credential_with_private_key(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.CLIENT_CERTIFICATE,
            certificate="abcdef",
            private_key="123456",
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>cc</type>"
            "<certificate>abcdef</certificate>"
            "<key>"
            "<private>123456</private>"
            "</key>"
            "</create_credential>"
        )

    def test_create_usk_credential_missing_private_key(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_credential(
                name="foo",
                credential_type=CredentialType.USERNAME_SSH_KEY,
                login="foo",
            )

    def test_create_usk_credential_missing_login(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_credential(
                name="foo",
                credential_type=CredentialType.USERNAME_SSH_KEY,
                private_key="123456",
            )

    def test_create_usk_credential(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.USERNAME_SSH_KEY,
            private_key="123456",
            login="foo",
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>usk</type>"
            "<login>foo</login>"
            "<key>"
            "<private>123456</private>"
            "</key>"
            "</create_credential>"
        )

    def test_create_usk_credential_with_key_phrase(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.USERNAME_SSH_KEY,
            private_key="123456",
            login="foo",
            key_phrase="abcdef",
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>usk</type>"
            "<login>foo</login>"
            "<key>"
            "<private>123456</private>"
            "<phrase>abcdef</phrase>"
            "</key>"
            "</create_credential>"
        )

    def test_create_snmp_credential_invalid_auth_algorithm(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_credential(
                name="foo", credential_type=CredentialType.SNMP, login="foo"
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_credential(
                name="foo",
                credential_type=CredentialType.SNMP,
                login="foo",
                auth_algorithm="",
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_credential(
                name="foo",
                credential_type=CredentialType.SNMP,
                login="foo",
                auth_algorithm="bar",
            )

    def test_create_snmp_credential_auth_algorithm_md5(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.SNMP,
            login="foo",
            auth_algorithm=SnmpAuthAlgorithm.MD5,
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>snmp</type>"
            "<login>foo</login>"
            "<auth_algorithm>md5</auth_algorithm>"
            "</create_credential>"
        )

    def test_create_snmp_credential_auth_algorithm_sha1(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.SNMP,
            login="foo",
            auth_algorithm=SnmpAuthAlgorithm.SHA1,
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>snmp</type>"
            "<login>foo</login>"
            "<auth_algorithm>sha1</auth_algorithm>"
            "</create_credential>"
        )

    def test_create_snmp_credential_with_community(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.SNMP,
            login="foo",
            auth_algorithm=SnmpAuthAlgorithm.SHA1,
            community="ipsum",
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>snmp</type>"
            "<login>foo</login>"
            "<auth_algorithm>sha1</auth_algorithm>"
            "<community>ipsum</community>"
            "</create_credential>"
        )

    def test_create_snmp_credential_invalid_privacy_algorithm(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_credential(
                name="foo",
                credential_type=CredentialType.SNMP,
                login="foo",
                auth_algorithm=SnmpAuthAlgorithm.SHA1,
                privacy_algorithm="",
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_credential(
                name="foo",
                credential_type=CredentialType.SNMP,
                login="foo",
                auth_algorithm=SnmpAuthAlgorithm.SHA1,
                privacy_algorithm="foo",
            )

    def test_create_snmp_credential_with_privacy_algorithm_aes(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.SNMP,
            login="foo",
            auth_algorithm=SnmpAuthAlgorithm.SHA1,
            privacy_algorithm=SnmpPrivacyAlgorithm.AES,
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>snmp</type>"
            "<login>foo</login>"
            "<auth_algorithm>sha1</auth_algorithm>"
            "<privacy>"
            "<algorithm>aes</algorithm>"
            "</privacy>"
            "</create_credential>"
        )

    def test_create_snmp_credential_with_privacy_algorithm_des(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.SNMP,
            login="foo",
            auth_algorithm=SnmpAuthAlgorithm.SHA1,
            privacy_algorithm=SnmpPrivacyAlgorithm.DES,
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>snmp</type>"
            "<login>foo</login>"
            "<auth_algorithm>sha1</auth_algorithm>"
            "<privacy>"
            "<algorithm>des</algorithm>"
            "</privacy>"
            "</create_credential>"
        )

    def test_create_snmp_credential_with_privacy_password(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.SNMP,
            login="foo",
            auth_algorithm=SnmpAuthAlgorithm.SHA1,
            privacy_password="123",
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>snmp</type>"
            "<login>foo</login>"
            "<auth_algorithm>sha1</auth_algorithm>"
            "<privacy>"
            "<password>123</password>"
            "</privacy>"
            "</create_credential>"
        )

    def test_create_smime_credential(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.SMIME_CERTIFICATE,
            certificate="ipsum",
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>smime</type>"
            "<certificate>ipsum</certificate>"
            "</create_credential>"
        )

    def test_create_smime_credential_missing_certificate(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_credential(
                name="foo", credential_type=CredentialType.SMIME_CERTIFICATE
            )

    def test_create_pgp_credential(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.PGP_ENCRYPTION_KEY,
            public_key="ipsum",
        )

        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>pgp</type>"
            "<key>"
            "<public>ipsum</public>"
            "</key>"
            "</create_credential>"
        )

    def test_create_pgp_credential_missing_public_key(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_credential(
                name="foo", credential_type=CredentialType.PGP_ENCRYPTION_KEY
            )

    def test_create_credential_invalid_credential_type(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_credential(name="foo", credential_type=None)

        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_credential(name="foo", credential_type="")

        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_credential(name="foo", credential_type="bar")

    def test_create_pw_credential_missing_password(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_credential(
                name="foo", credential_type=CredentialType.PASSWORD_ONLY
            )

    def test_create_pw_credential(self):
        self.gmp.create_credential(
            name="foo",
            credential_type=CredentialType.PASSWORD_ONLY,
            password="foo",
        )
        self.connection.send.has_been_called_with(
            "<create_credential>"
            "<name>foo</name>"
            "<type>pw</type>"
            "<password>foo</password>"
            "</create_credential>"
        )



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


class GmpGetCveListTestMixin:
    def test_get_cpes(self):
        self.gmp.get_cves()

        self.connection.send.has_been_called_with('<get_info type="CVE"/>')

    def test_get_cves_with_filter_string(self):
        self.gmp.get_cves(filter_string="foo=bar")

        self.connection.send.has_been_called_with(
            '<get_info type="CVE" filter="foo=bar"/>'
        )

    def test_get_cves_with_filter_id(self):
        self.gmp.get_cves(filter_id="f1")

        self.connection.send.has_been_called_with(
            '<get_info type="CVE" filt_id="f1"/>'
        )

    def test_get_cves_with_name(self):
        self.gmp.get_cves(name="foo")

        self.connection.send.has_been_called_with(
            '<get_info type="CVE" name="foo"/>'
        )

    def test_get_cves_with_details(self):
        self.gmp.get_cves(details=True)

        self.connection.send.has_been_called_with(
            '<get_info type="CVE" details="1"/>'
        )

        self.gmp.get_cves(details=False)

        self.connection.send.has_been_called_with(
            '<get_info type="CVE" details="0"/>'
        )



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from collections import OrderedDict

from gvm.errors import InvalidArgument, InvalidArgumentType, RequiredArgument
from gvm.protocols.gmpv208 import HostsOrdering


class GmpCreateAuditTestMixin:
    def test_create_audit(self):
        self.gmp.create_audit(
            name="foo", policy_id="c1", target_id="t1", scanner_id="s1"
        )

        self.connection.send.has_been_called_with(
            "<create_task>"
            "<name>foo</name>"
            "<usage_type>audit</usage_type>"
            '<config id="c1"/>'
            '<target id="t1"/>'
            '<scanner id="s1"/>'
            "</create_task>"
        )

    def test_create_audit_missing_name(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_audit(
                name=None, policy_id="c1", target_id="t1", scanner_id="s1"
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.create_audit(
                name="", policy_id="c1", target_id="t1", scanner_id="s1"
            )

    def test_create_audit_missing_policy_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_audit(
                name="foo", policy_id=None, target_id="t1", scanner_id="s1"
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.create_audit(
                name="foo", policy_id="", target_id="t1", scanner_id="s1"
            )

    def test_create_audit_missing_target_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_audit(
                name="foo", policy_id="c1", target_id=None, scanner_id="s1"
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.create_audit(
                name="foo", policy_id="c1", target_id="", scanner_id="s1"
            )

    def test_create_audit_missing_scanner_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_audit(
                name="foo", policy_id="c1", target_id="t1", scanner_id=None
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.create_audit(
                name="foo", policy_id="c1", target_id="t1", scanner_id=""
            )

    def test_create_audit_with_comment(self):
        self.gmp.create_audit(
            name="foo",
            policy_id="c1",
            target_id="t1",
            scanner_id="s1",
            comment="bar",
        )

        self.connection.send.has_been_called_with(
            "<create_task>"
            "<name>foo</name>"
            "<usage_type>audit</usage_type>"
            '<config id="c1"/>'
            '<target id="t1"/>'
            '<scanner id="s1"/>'
            "<comment>bar</comment>"
            "</create_task>"
        )

    def test_create_audit_single_alert(self):
        # pylint: disable=invalid-name
        self.gmp.create_audit(
            name="foo",
            policy_id="c1",
            target_id="t1",
            scanner_id="s1",
            alert_ids=["a1"],
        )

        self.connection.send.has_been_called_with(
            "<create_task>"
            "<name>foo</name>"
            "<usage_type>audit</usage_type>"
            '<config id="c1"/>'
            '<target id="t1"/>'
            '<scanner id="s1"/>'
            '<alert id="a1"/>'
            "</create_task>"
        )

    def test_create_audit_multiple_alerts(self):
        self.gmp.create_audit(
            name="foo",
            policy_id="c1",
            target_id="t1",
            scanner_id="s1",
            alert_ids=["a1", "a2", "a3"],
        )

        self.connection.send.has_been_called_with(
            "<create_task>"
            "<name>foo</name>"
            "<usage_type>audit</usage_type>"
            '<config id="c1"/>'
            '<target id="t1"/>'
            '<scanner id="s1"/>'
            '<alert id="a1"/>'
            '<alert id="a2"/>'
            '<alert id="a3"/>'
            "</create_task>"
        )

    def test_create_audit_invalid_alerts(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_audit(
                name="foo",
                policy_id="c1",
                target_id="t1",
                scanner_id="s1",
                alert_ids="invalid",
            )

    def test_create_audit_with_empty_alert_ids(self):
        self.gmp.create_audit(
            name="foo",
            policy_id="c1",
            target_id="t1",
            scanner_id="s1",
            alert_ids=[],
        )

        self.connection.send.has_been_called_with(
            "<create_task>"
            "<name>foo</name>"
            "<usage_type>audit</usage_type>"
            '<config id="c1"/>'
            '<target id="t1"/>'
            '<scanner id="s1"/>'
            "</create_task>"
        )

    def test_create_audit_with_alterable(self):
        self.gmp.create_audit(
            name="foo",
            policy_id="c1",
            target_id="t1",
            scanner_id="s1",
            alterable=True,
        )

        self.connection.send.has_been_called_with(
            "<create_task>"
            "<name>foo</name>"
            "<usage_type>audit</usage_type>"
            '<config id="c1"/>'
            '<target id="t1"/>'
            '<scanner id="s1"/>'
            "<alterable>1</alterable>"
            "</create_task>"
        )

        self.gmp.create_audit(
            name="foo",
            policy_id="c1",
            target_id="t1",
            scanner_id="s1",
            alterable=False,
        )

        self.connection.send.has_been_called_with(
            "<create_task>"
            "<name>foo</name>"
            "<usage_type>audit</usage_type>"
            '<config id="c1"/>'
            '<target id="t1"/>'
            '<scanner id="s1"/>'
            "<alterable>0</alterable>"
            "</create_task>"
        )

    def test_create_audit_with_hosts_ordering(self):
        self.gmp.create_audit(
            name="foo",
            policy_id="c1",
            target_id="t1",
            scanner_id="s1",
            hosts_ordering=HostsOrdering.REVERSE,
        )

        self.connection.send.has_been_called_with(
            "<create_task>"
            "<name>foo</name>"
            "<usage_type>audit</usage_type>"
            '<config id="c1"/>'
            '<target id="t1"/>'
            '<scanner id="s1"/>'
            "<hosts_ordering>reverse</hosts_ordering>"
            "</create_task>"
        )

    def test_create_audit_invalid_hosts_ordering(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_audit(
                name="foo",
                policy_id="c1",
                target_id="t1",
                scanner_id="s1",
                hosts_ordering="foo",
            )

    def test_create_audit_with_schedule(self):
        self.gmp.create_audit(
            name="foo",
            policy_id="c1",
            target_id="t1",
            scanner_id="s1",
            schedule_id="s1",
        )

        self.connection.send.has_been_called_with(
            "<create_task>"
            "<name>foo</name>"
            "<usage_type>audit</usage_type>"
            '<config id="c1"/>'
            '<target id="t1"/>'
            '<scanner id="s1"/>'
            '<schedule id="s1"/>'
            "</create_task>"
        )

    def test_create_audit_with_schedule_and_schedule_periods(self):
        self.gmp.create_audit(
            name="foo",
            policy_id="c1",
            target_id="t1",
            scanner_id="s1",
            schedule_id="s1",
            schedule_periods=0,
        )

        self.connection.send.has_been_called_with(
            "<create_task>"
            "<name>foo</name>"
            "<usage_type>audit</usage_type>"
            '<config id="c1"/>'
            '<target id="t1"/>'
            '<scanner id="s1"/>'
            '<schedule id="s1"/>'
            "<schedule_periods>0</schedule_periods>"
            "</create_task>"
        )

        self.gmp.create_audit(
            name="foo",
            policy_id="c1",
            target_id="t1",
            scanner_id="s1",
            schedule_id="s1",
            schedule_periods=5,
        )

        self.connection.send.has_been_called_with(
            "<create_task>"
            "<name>foo</name>"
            "<usage_type>audit</usage_type>"
            '<config id="c1"/>'
            '<target id="t1"/>'
            '<scanner id="s1"/>'
            '<schedule id="s1"/>'
            "<schedule_periods>5</schedule_periods>"
            "</create_task>"
        )

    def test_create_audit_with_schedule_and_invalid_schedule_periods(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.create_audit(
                name="foo",
                policy_id="c1",
                target_id="t1",
                scanner_id="s1",
                schedule_id="s1",
                schedule_periods="foo",
            )

        with self.assertRaises(InvalidArgument):
            self.gmp.create_audit(
                name="foo",
                policy_id="c1",
                target_id="t1",
                scanner_id="s1",
                schedule_id="s1",
                schedule_periods=-1,
            )

    def test_create_audit_with_observers(self):
        self.gmp.create_audit(
            name="foo",
            policy_id="c1",
            target_id="t1",
            scanner_id="s1",
            observers=["u1", "u2"],
        )

        self.connection.send.has_been_called_with(
            "<create_task>"
            "<name>foo</name>"
            "<usage_type>audit</usage_type>"
            '<config id="c1"/>'
            '<target id="t1"/>'
            '<scanner id="s1"/>'
            "<observers>u1,u2</observers>"
            "</create_task>"
        )

    def test_create_audit_invalid_observers(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_audit(
                name="foo",
                policy_id="c1",
                target_id="t1",
                scanner_id="s1",
                observers="",
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_audit(
                name="foo",
                policy_id="c1",
                target_id="t1",
                scanner_id="s1",
                observers="foo",
            )

    def test_create_audit_with_preferences(self):
        self.gmp.create_audit(
            name="foo",
            policy_id="c1",
            target_id="t1",
            scanner_id="s1",
            preferences=OrderedDict([("foo", "bar"), ("lorem", "ipsum")]),
        )

        self.connection.send.has_been_called_with(
            "<create_task>"
            "<name>foo</name>"
            "<usage_type>audit</usage_type>"
            '<config id="c1"/>'
            '<target id="t1"/>'
            '<scanner id="s1"/>'
            "<preferences>"
            "<preference>"
            "<scanner_name>foo</scanner_name>"
            "<value>bar</value>"
            "</preference>"
            "<preference>"
            "<scanner_name>lorem</scanner_name>"
            "<value>ipsum</value>"
            "</preference>"
            "</preferences>"
            "</create_task>"
        )

    def test_create_audit_invalid_preferences(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_audit(
                name="foo",
                policy_id="c1",
                target_id="t1",
                scanner_id="s1",
                preferences="",
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_audit(
                name="foo",
                policy_id="c1",
                target_id="t1",
                scanner_id="s1",
                preferences=["foo", "bar"],
            )

    def test_create_audit_don_t_allow_container_task(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.create_audit(
                name="foo",
                policy_id="c1",
                target_id="0",
                scanner_id="s1",
                observers="",
            )

        # target_id=0 is considered as False
        with self.assertRaises(RequiredArgument):
            self.gmp.create_audit(
                name="foo",
                policy_id="c1",
                target_id=0,
                scanner_id="s1",
                observers="",
            )



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import RequiredArgument


class GmpGetScanConfigNvtTestMixin:
    def test_get_scan_config_nvt_with_nvt_oid(self):
        self.gmp.get_scan_config_nvt(nvt_oid="nvt_oid")

        self.connection.send.has_been_called_with(
            (
                '<get_nvts nvt_oid="nvt_oid" details="1" '
                'preferences="1" preference_count="1"/>'
            )
        )

    def test_get_scan_config_nvt_missing_nvt_oid(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.get_scan_config_nvt(nvt_oid=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.get_scan_config_nvt(nvt_oid="")

        with self.assertRaises(RequiredArgument):
            self.gmp.get_scan_config_nvt("")



# -*- coding: utf-8 -*-
# Copyright (C) 2021-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from gvm.errors import InvalidArgument
from gvm.protocols.gmpv214 import AlertCondition


class GetAlertConditionFromStringTestCase(unittest.TestCase):
    def test_invalid(self):
        with self.assertRaises(InvalidArgument):
            AlertCondition.from_string("foo")

    def test_none_or_empty(self):
        ct = AlertCondition.from_string(None)
        self.assertIsNone(ct)
        ct = AlertCondition.from_string("")
        self.assertIsNone(ct)

    def test_always(self):
        ct = AlertCondition.from_string("always")
        self.assertEqual(ct, AlertCondition.ALWAYS)

    def test_filter_count_at_least(self):
        ct = AlertCondition.from_string("filter count at least")
        self.assertEqual(ct, AlertCondition.FILTER_COUNT_AT_LEAST)

    def test_filter_count_changed(self):
        ct = AlertCondition.from_string("filter count changed")
        self.assertEqual(ct, AlertCondition.FILTER_COUNT_CHANGED)

    def test_severity_at_least(self):
        ct = AlertCondition.from_string("severity at least")
        self.assertEqual(ct, AlertCondition.SEVERITY_AT_LEAST)

    def test_severity_changed(self):
        ct = AlertCondition.from_string("severity changed")
        self.assertEqual(ct, AlertCondition.SEVERITY_CHANGED)

    def test_error(self):
        ct = AlertCondition.from_string("error")
        self.assertEqual(ct, AlertCondition.ERROR)


if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys
from io import IOBase
from typing import List, Optional, Union

import defusedxml.lxml as secET
from defusedxml import DefusedXmlException
from lxml.etree import Element, LxmlError, SubElement, XMLParser
from lxml.etree import iselement as isxmlelement
from lxml.etree import tostring as xmltostring

from gvm.errors import GvmError, InvalidArgumentType


def create_parser():
    # huge_tree => disable security restrictions and support very deep trees and
    #              very long text content (for get_reports)
    return XMLParser(encoding="utf-8", huge_tree=True)


class XmlCommandElement:
    def __init__(self, element):
        self._element = element

    def add_element(
        self,
        name: str,
        text: Optional[str] = None,
        *,
        attrs: Optional[dict] = None,
    ):
        node = SubElement(self._element, name, attrib=attrs)
        node.text = text
        return XmlCommandElement(node)

    def set_attribute(self, name: str, value: str):
        self._element.set(name, value)

    def set_attributes(self, attrs: dict):
        """Set several attributes at once.

        Arguments:
            attrs (dict): Attributes to be set on the element
        """
        for key, value in attrs.items():
            self._element.set(key, value)

    def append_xml_str(self, xml_text: str):
        """Append a xml element in string format."""
        node = secET.fromstring(xml_text)
        self._element.append(node)

    def to_string(self) -> str:
        return xmltostring(self._element).decode("utf-8")

    def __str__(self):
        return self.to_string()


class XmlCommand(XmlCommandElement):
    def __init__(self, name):
        super().__init__(Element(name))


def pretty_print(
    xml: Union[str, List[Union[Element, str]], Element],
    file: IOBase = sys.stdout,
):
    """Prints beautiful XML-Code

    This function gets a string containing the xml, an object of
    List[lxml.etree.Element] or directly a lxml element.

    Print it with good readable format.

    Arguments:
        xml (str, List[lxml.etree.Element] or lxml.etree.Element):
            xml as string,
            List[lxml.etree.Element] or directly a lxml element.
        file:
            A IOBase type. Can be a File, StringIO, ...

    """
    if not isinstance(file, IOBase):
        raise TypeError(
            f"Type needs to be from IOBase, not {type(file)}."
        ) from None

    if isinstance(xml, list):
        for item in xml:
            if isxmlelement(item):
                file.write(
                    xmltostring(item, pretty_print=True).decode(
                        sys.getdefaultencoding() + "\n"
                    )
                )
            else:
                file.write(item + "\n")
    elif isxmlelement(xml):
        file.write(
            xmltostring(xml, pretty_print=True).decode(
                sys.getdefaultencoding() + "\n"
            )
        )
    elif isinstance(xml, str):
        tree = secET.fromstring(xml)
        file.write(
            xmltostring(tree, pretty_print=True).decode(
                sys.getdefaultencoding() + "\n"
            )
        )
    else:
        raise InvalidArgumentType(
            function=pretty_print.__name__, argument="xml", arg_type=""
        )


def validate_xml_string(xml_string: str):
    """Checks if the passed string contains valid XML

    Raises a GvmError if the XML is invalid. Otherwise the function just
    returns.

    Arguments:
        xml_string: XML string to validate

    Raises:
        GvmError: The xml string did contain invalid XML

    """
    try:
        secET.fromstring(xml_string)
    except (DefusedXmlException, LxmlError) as e:
        raise GvmError("Invalid XML", e) from e



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import InvalidArgumentType, RequiredArgument
from gvm.protocols.gmpv208.entities.targets import AliveTest


class GmpCreateTargetTestMixin:
    def test_create_target_missing_name(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_target(None, hosts=["foo"])

        with self.assertRaises(RequiredArgument):
            self.gmp.create_target(name=None, hosts=["foo"])

        with self.assertRaises(RequiredArgument):
            self.gmp.create_target("", hosts=["foo"])

    def test_create_target_with_asset_hosts_filter(self):
        self.gmp.create_target(
            "foo", port_list_id="pl1", asset_hosts_filter="name=foo"
        )

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            '<asset_hosts filter="name=foo"/>'
            '<port_list id="pl1"/>'
            "</create_target>"
        )

    def test_create_target_missing_hosts(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_target(name="foo")

    def test_create_target_with_comment(self):
        self.gmp.create_target(
            "foo", hosts=["foo"], port_list_id="pl1", comment="bar"
        )

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo</hosts>"
            "<comment>bar</comment>"
            '<port_list id="pl1"/>'
            "</create_target>"
        )

    def test_create_target_with_exclude_hosts(self):
        self.gmp.create_target(
            "foo",
            hosts=["foo", "bar"],
            port_list_id="pl1",
            exclude_hosts=["bar", "ipsum"],
        )

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo,bar</hosts>"
            "<exclude_hosts>bar,ipsum</exclude_hosts>"
            '<port_list id="pl1"/>'
            "</create_target>"
        )

    def test_create_target_with_ssh_credential(self):
        self.gmp.create_target(
            "foo", hosts=["foo"], port_list_id="pl1", ssh_credential_id="c1"
        )

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo</hosts>"
            '<ssh_credential id="c1"/>'
            '<port_list id="pl1"/>'
            "</create_target>"
        )

    def test_create_target_with_ssh_credential_port(self):
        self.gmp.create_target(
            "foo",
            hosts=["foo"],
            port_list_id="pl1",
            ssh_credential_id="c1",
            ssh_credential_port=123,
        )

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo</hosts>"
            '<ssh_credential id="c1">'
            "<port>123</port>"
            "</ssh_credential>"
            '<port_list id="pl1"/>'
            "</create_target>"
        )

    def test_create_target_with_smb_credential_id(self):
        self.gmp.create_target(
            "foo", hosts=["foo"], port_list_id="pl1", smb_credential_id="c1"
        )

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo</hosts>"
            '<smb_credential id="c1"/>'
            '<port_list id="pl1"/>'
            "</create_target>"
        )

    def test_create_target_with_esxi_credential_id(self):
        self.gmp.create_target(
            "foo", hosts=["foo"], port_list_id="pl1", esxi_credential_id="c1"
        )

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo</hosts>"
            '<esxi_credential id="c1"/>'
            '<port_list id="pl1"/>'
            "</create_target>"
        )

    def test_create_target_with_snmp_credential_id(self):
        self.gmp.create_target(
            "foo", hosts=["foo"], port_list_id="pl1", snmp_credential_id="c1"
        )

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo</hosts>"
            '<snmp_credential id="c1"/>'
            '<port_list id="pl1"/>'
            "</create_target>"
        )

    def test_create_target_with_alive_tests(self):
        self.gmp.create_target(
            "foo",
            hosts=["foo"],
            port_list_id="pl1",
            alive_test=AliveTest.ICMP_PING,
        )

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo</hosts>"
            "<alive_tests>ICMP Ping</alive_tests>"
            '<port_list id="pl1"/>'
            "</create_target>"
        )

    def test_create_target_invalid_alive_tests(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.create_target(
                "foo", hosts=["foo"], port_list_id="pl1", alive_test="foo"
            )

    def test_create_target_with_reverse_lookup_only(self):
        self.gmp.create_target(
            "foo", hosts=["foo"], port_list_id="pl1", reverse_lookup_only=True
        )

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo</hosts>"
            "<reverse_lookup_only>1</reverse_lookup_only>"
            '<port_list id="pl1"/>'
            "</create_target>"
        )

        self.gmp.create_target(
            "foo", hosts=["foo"], port_list_id="pl1", reverse_lookup_only=False
        )

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo</hosts>"
            "<reverse_lookup_only>0</reverse_lookup_only>"
            '<port_list id="pl1"/>'
            "</create_target>"
        )

    def test_create_target_with_reverse_lookup_unify(self):
        self.gmp.create_target(
            "foo", hosts=["foo"], port_list_id="pl1", reverse_lookup_unify=True
        )

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo</hosts>"
            "<reverse_lookup_unify>1</reverse_lookup_unify>"
            '<port_list id="pl1"/>'
            "</create_target>"
        )

        self.gmp.create_target(
            "foo", hosts=["foo"], port_list_id="pl1", reverse_lookup_unify=False
        )

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo</hosts>"
            "<reverse_lookup_unify>0</reverse_lookup_unify>"
            '<port_list id="pl1"/>'
            "</create_target>"
        )

    def test_create_target_with_port_range(self):
        self.gmp.create_target("foo", hosts=["foo"], port_range="bar")

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo</hosts>"
            "<port_range>bar</port_range>"
            "</create_target>"
        )

    def test_create_target_with_port_list_id(self):
        self.gmp.create_target("foo", hosts=["foo"], port_list_id="pl1")

        self.connection.send.has_been_called_with(
            "<create_target>"
            "<name>foo</name>"
            "<hosts>foo</hosts>"
            '<port_list id="pl1"/>'
            "</create_target>"
        )

    def test_create_target_without_ports(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_target("foo", hosts=["foo"])



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import InvalidArgumentType, RequiredArgument
from gvm.protocols.gmpv208 import AlertCondition, AlertEvent, AlertMethod


class GmpModifyAlertTestMixin:
    def test_modify_alert(self):
        self.gmp.modify_alert(alert_id="a1")

        self.connection.send.has_been_called_with(
            '<modify_alert alert_id="a1"/>'
        )

    def test_modify_alert_without_alert_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_alert(alert_id=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_alert(alert_id="")

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_alert("")

    def test_modify_alert_with_comment(self):
        self.gmp.modify_alert(alert_id="a1", comment="lorem")

        self.connection.send.has_been_called_with(
            '<modify_alert alert_id="a1">'
            "<comment>lorem</comment>"
            "</modify_alert>"
        )

    def test_modify_alert_with_name(self):
        self.gmp.modify_alert(alert_id="a1", name="lorem")

        self.connection.send.has_been_called_with(
            '<modify_alert alert_id="a1">'
            "<name>lorem</name>"
            "</modify_alert>"
        )

    def test_modify_alert_with_filter_id(self):
        self.gmp.modify_alert(alert_id="a1", filter_id="f1")

        self.connection.send.has_been_called_with(
            '<modify_alert alert_id="a1">' '<filter id="f1"/>' "</modify_alert>"
        )

    def test_modify_alert_invalid_condition(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_alert(
                alert_id="a1",
                condition="bar",
                event=AlertEvent.TASK_RUN_STATUS_CHANGED,
                method=AlertMethod.SCP,
            )

    def test_modify_alert_invalid_event(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_alert(
                alert_id="a1",
                condition=AlertCondition.ALWAYS,
                event="lorem",
                method=AlertMethod.SCP,
            )

    def test_modify_alert_invalid_method(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_alert(
                alert_id="a1",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TASK_RUN_STATUS_CHANGED,
                method="ipsum",
            )

    def test_modify_alert_with_event_missing_method(self):
        with self.assertRaisesRegex(RequiredArgument, "method is required"):
            self.gmp.modify_alert(
                alert_id="a1",
                event=AlertEvent.TASK_RUN_STATUS_CHANGED,
                condition=AlertCondition.ALWAYS,
            )

        with self.assertRaisesRegex(RequiredArgument, "method is required"):
            self.gmp.modify_alert(
                alert_id="a1",
                event=AlertEvent.NEW_SECINFO_ARRIVED,
                condition=AlertCondition.ALWAYS,
            )

        with self.assertRaisesRegex(RequiredArgument, "method is required"):
            self.gmp.modify_alert(
                alert_id="a1",
                event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                condition=AlertCondition.ALWAYS,
            )

    def test_modify_alert_with_event_missing_condition(self):
        with self.assertRaisesRegex(RequiredArgument, "condition is required"):
            self.gmp.modify_alert(
                alert_id="a1",
                event=AlertEvent.TASK_RUN_STATUS_CHANGED,
                method=AlertMethod.SCP,
            )

        with self.assertRaisesRegex(RequiredArgument, "condition is required"):
            self.gmp.modify_alert(
                alert_id="a1",
                event=AlertEvent.NEW_SECINFO_ARRIVED,
                method=AlertMethod.SCP,
            )

        with self.assertRaisesRegex(RequiredArgument, "condition is required"):
            self.gmp.modify_alert(
                alert_id="a1",
                event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                method=AlertMethod.SCP,
            )

    def test_modify_alert_invalid_condition_for_secinfo(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_alert(
                alert_id="a1",
                condition="Severity at least",
                event="Updated SecInfo arrived",
                method="Email",
            )

    def test_modify_alert_invalid_method_for_secinfo(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_alert(
                alert_id="a1",
                condition="Always",
                event="Updated SecInfo arrived",
                method="HTTP Get",
            )

    def test_modify_alert_with_event_data(self):
        self.gmp.modify_alert(
            alert_id="a1",
            condition=AlertCondition.ALWAYS,
            event=AlertEvent.TASK_RUN_STATUS_CHANGED,
            method=AlertMethod.EMAIL,
            event_data={"foo": "bar"},
        )

        self.connection.send.has_been_called_with(
            '<modify_alert alert_id="a1">'
            "<condition>Always</condition>"
            "<method>Email</method>"
            "<event>Task run status changed"
            "<data>bar<name>foo</name></data>"
            "</event>"
            "</modify_alert>"
        )

    def test_modify_alert_with_condition_data(self):
        self.gmp.modify_alert(
            alert_id="a1",
            condition=AlertCondition.ALWAYS,
            event=AlertEvent.TASK_RUN_STATUS_CHANGED,
            method=AlertMethod.EMAIL,
            condition_data={"foo": "bar"},
        )

        self.connection.send.has_been_called_with(
            '<modify_alert alert_id="a1">'
            "<condition>Always<data>bar<name>foo</name></data></condition>"
            "<method>Email</method>"
            "<event>Task run status changed</event>"
            "</modify_alert>"
        )

    def test_modify_alert_with_method_data(self):
        self.gmp.modify_alert(
            alert_id="a1",
            condition=AlertCondition.ALWAYS,
            event=AlertEvent.TASK_RUN_STATUS_CHANGED,
            method=AlertMethod.EMAIL,
            method_data={"foo": "bar"},
        )

        self.connection.send.has_been_called_with(
            '<modify_alert alert_id="a1">'
            "<condition>Always</condition>"
            "<method>Email<data>bar<name>foo</name></data></method>"
            "<event>Task run status changed</event>"
            "</modify_alert>"
        )

    def test_modify_missing_method_for_ticket_received(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_alert(
                alert_id="a1",
                condition=AlertCondition.ALWAYS,
                event=AlertEvent.TICKET_RECEIVED,
                method=None,
            )

    def test_modify_missing_condition_for_ticket_received(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_alert(
                alert_id="a1",
                condition=None,
                event=AlertEvent.TICKET_RECEIVED,
                method=AlertMethod.EMAIL,
            )



# -*- coding: utf-8 -*-
# Copyright (C) 2021-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from ...gmpv208 import Gmpv208TestCase
from .notes import (
    GmpCloneNoteTestMixin,
    GmpCreateNoteTestMixin,
    GmpDeleteNoteTestMixin,
    GmpGetNotesTestMixin,
    GmpGetNoteTestMixin,
    GmpModifyNoteTestMixin,
)


class Gmpv208DeleteNoteTestCase(GmpDeleteNoteTestMixin, Gmpv208TestCase):
    pass


class Gmpv208GetNoteTestCase(GmpGetNoteTestMixin, Gmpv208TestCase):
    pass


class Gmpv208GetNotesTestCase(GmpGetNotesTestMixin, Gmpv208TestCase):
    pass


class Gmpv208CloneNoteTestCase(GmpCloneNoteTestMixin, Gmpv208TestCase):
    pass


class Gmpv208CreateNoteTestCase(GmpCreateNoteTestMixin, Gmpv208TestCase):
    pass


class Gmpv208ModifyNoteTestCase(GmpModifyNoteTestMixin, Gmpv208TestCase):
    pass



# -*- coding: utf-8 -*-
# Copyright (C) 2019-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import RequiredArgument


class GmpCreateTicketTestMixin:
    def test_create_ticket(self):
        self.gmp.create_ticket(
            result_id="r1", assigned_to_user_id="u1", note="lorem ipsum"
        )

        self.connection.send.has_been_called_with(
            "<create_ticket>"
            '<result id="r1"/>'
            "<assigned_to>"
            '<user id="u1"/>'
            "</assigned_to>"
            "<open_note>lorem ipsum</open_note>"
            "</create_ticket>"
        )

    def test_create_ticket_with_comment(self):
        self.gmp.create_ticket(
            result_id="r1",
            assigned_to_user_id="u1",
            note="lorem ipsum",
            comment="bar",
        )

        self.connection.send.has_been_called_with(
            "<create_ticket>"
            '<result id="r1"/>'
            "<assigned_to>"
            '<user id="u1"/>'
            "</assigned_to>"
            "<open_note>lorem ipsum</open_note>"
            "<comment>bar</comment>"
            "</create_ticket>"
        )

    def test_create_ticket_missing_result_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_ticket(
                result_id="", assigned_to_user_id="u1", note="lorem ipsum"
            )

    def test_create_ticket_missing_assigned_to_user_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_ticket(
                result_id="r1", assigned_to_user_id="", note="lorem ipsum"
            )

    def test_create_ticket_missing_open_note(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_ticket(
                result_id="r1", assigned_to_user_id="u1", note=""
            )



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


class GmpGetTLSCertificatesTestMixin:
    def test_get_tls_certificates(self):
        self.gmp.get_tls_certificates()

        self.connection.send.has_been_called_with("<get_tls_certificates/>")

    def test_get_tls_certificates_with_filter_string(self):
        self.gmp.get_tls_certificates(filter_string="name=foo")

        self.connection.send.has_been_called_with(
            '<get_tls_certificates filter="name=foo"/>'
        )

    def test_get_tls_certificates_with_include_certificate_data(self):
        self.gmp.get_tls_certificates(include_certificate_data="1")

        self.connection.send.has_been_called_with(
            '<get_tls_certificates include_certificate_data="1"/>'
        )

    def test_get_tls_certificates_with_details(self):
        self.gmp.get_tls_certificates(details="1")

        self.connection.send.has_been_called_with(
            '<get_tls_certificates details="1"/>'
        )



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from collections import OrderedDict

from gvm.errors import RequiredArgument


class GmpModifyAuthTestMixin:
    def test_modify_auth(self):
        self.gmp.modify_auth(
            "foo", OrderedDict([("foo", "bar"), ("lorem", "ipsum")])
        )

        self.connection.send.has_been_called_with(
            "<modify_auth>"
            '<group name="foo">'
            "<auth_conf_setting>"
            "<key>foo</key>"
            "<value>bar</value>"
            "</auth_conf_setting>"
            "<auth_conf_setting>"
            "<key>lorem</key>"
            "<value>ipsum</value>"
            "</auth_conf_setting>"
            "</group>"
            "</modify_auth>"
        )

    def test_modify_auth_missing_group_name(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_auth(
                group_name=None, auth_conf_settings={"foo": "bar"}
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_auth(
                group_name="", auth_conf_settings={"foo": "bar"}
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_auth("", auth_conf_settings={"foo": "bar"})

    def test_modify_auth_auth_conf_settings(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_auth(group_name="foo", auth_conf_settings=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_auth(group_name="foo", auth_conf_settings="")

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_auth("foo", "")

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_auth("foo", {})



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


class GmpGetResultsTestMixin:
    def test_get_results(self):
        self.gmp.get_results()

        self.connection.send.has_been_called_with("<get_results/>")

    def test_get_results_with_filter_string(self):
        self.gmp.get_results(filter_string="foo=bar")

        self.connection.send.has_been_called_with(
            '<get_results filter="foo=bar"/>'
        )

    def test_get_results_with_filter_id(self):
        self.gmp.get_results(filter_id="f1")

        self.connection.send.has_been_called_with('<get_results filt_id="f1"/>')

    def test_get_results_with_note_details(self):
        self.gmp.get_results(note_details=True)

        self.connection.send.has_been_called_with(
            '<get_results note_details="1"/>'
        )

        self.gmp.get_results(note_details=False)

        self.connection.send.has_been_called_with(
            '<get_results note_details="0"/>'
        )

    def test_get_results_with_override_details(self):
        self.gmp.get_results(override_details=True)

        self.connection.send.has_been_called_with(
            '<get_results override_details="1"/>'
        )

        self.gmp.get_results(override_details=False)

        self.connection.send.has_been_called_with(
            '<get_results override_details="0"/>'
        )

    def test_get_results_with_details(self):
        self.gmp.get_results(details=True)

        self.connection.send.has_been_called_with('<get_results details="1"/>')

        self.gmp.get_results(details=False)

        self.connection.send.has_been_called_with('<get_results details="0"/>')

    def test_get_results_with_task_id(self):
        self.gmp.get_results(task_id="t1")

        self.connection.send.has_been_called_with('<get_results task_id="t1"/>')
